package com.community.huiju.controller;

import com.community.commom.constant.Constant;
import com.community.commom.mode.ResponseBean;
import com.community.commom.session.UserElement;
import com.community.huiju.model.TpActivity;
import com.community.huiju.model.TpAnnouncement;
import com.community.huiju.model.TpTicket;
import com.community.huiju.model.TpTransaction;
import com.community.huiju.service.SocialServiceI;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.context.config.annotation.RefreshScope;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpSession;
import java.io.IOException;
import java.util.List;

/**
 * @author weichaochao
 * @Title: SocialController
 * @date 2018/10/23
 */
@RestController
@RefreshScope
@RequestMapping("/")
@Api(value = "app端论坛相关的API", description = "app端论坛相关的API")
public class SocialController {

    @Autowired
    private SocialServiceI socialServiceI;

    @RequestMapping(value = "/announcement/{communityId}", method = RequestMethod.GET)
    @ApiOperation(value = "论坛公告帖子详情", notes = "获取论坛公告帖子详情")
    @ApiImplicitParams({@ApiImplicitParam(paramType = "path", dataType = "integer", name = "communityId", value = "小区Id"),
            @ApiImplicitParam(paramType = "query", dataType = "integer", name = "id", value = "公告帖子id"),
            @ApiImplicitParam(paramType = "header",dataType = "String",name = "X-Auth-Token",value = "Token")})
    public ResponseBean findAnnouncementDetail(@PathVariable(value = "communityId") Integer communityId, @RequestParam("id") Integer id, HttpSession session) {
        UserElement userElement = (UserElement) session.getAttribute(Constant.APP_USER_SESSION);
        Integer userId = userElement.getId();
        ResponseBean responseBean = new ResponseBean();
        TpAnnouncement tpAnnouncement = socialServiceI.findAnnouncementDetail(id, communityId, userId);
        responseBean.addSuccess(tpAnnouncement);
        return responseBean;
    }

    @RequestMapping(value = "/sign/{communityId}", method = RequestMethod.POST)
    @ApiOperation(value = "活动报名接口", notes = "活动报名接口")
    @ApiImplicitParams({@ApiImplicitParam(paramType = "path", dataType = "integer", name = "communityId", value = "小区Id"),
            @ApiImplicitParam(paramType = "query", dataType = "integer", name = "activityId", value = "活动Id"),
            @ApiImplicitParam(paramType = "header",dataType = "String",name = "X-Auth-Token",value = "Token")})
    public ResponseBean SignActivity(@PathVariable(value = "communityId") Integer communityId, @RequestParam("activityId") Integer activityId, HttpSession session) {
        UserElement userElement = (UserElement) session.getAttribute(Constant.APP_USER_SESSION);
        Integer userId = userElement.getId();
        ResponseBean responseBean = socialServiceI.findTaUserInfo(activityId, communityId, userId);
        return responseBean;
    }

    @ApiOperation(value = "按小区获取分页公告列表", notes = "按小区获取分页公告列表,公告标题模糊查询")
    @ApiImplicitParams({@ApiImplicitParam(paramType = "path", dataType = "String", name = "communityId", value = "小区Id"),
            @ApiImplicitParam(paramType = "query", dataType = "String", name = "title", value = "公告标题"),
            @ApiImplicitParam(paramType = "query", dataType = "integer", name = "pageNum", value = "分页第几页"),
            @ApiImplicitParam(paramType = "query", dataType = "integer", name = "pageSize", value = "分页每页长度")})
    @RequestMapping(value = "/announcements/{communityId}", method = RequestMethod.GET)
    public ResponseBean getAnnouncements(@PathVariable Integer communityId, @RequestParam String title,
                                         @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                         @RequestParam(value = "pageSize", defaultValue = "5") Integer pageSize) {
        ResponseBean responseBean = new ResponseBean();
        List<TpAnnouncement> announcementList = socialServiceI.getAnnouncements(communityId, title, pageNum, pageSize);
        responseBean.addSuccess(announcementList);
        return responseBean;
    }

    @ApiOperation(value = "获取公告轮播图", notes = "获取公告轮播图")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataType = "String", name = "communityId", value = "小区id")
    })
    @RequestMapping(value = "/announcement/Img/{communityId}", method = RequestMethod.GET)
    public ResponseBean getAnnouncement(@PathVariable(value = "communityId") Integer communityId) {
        ResponseBean responseBean = new ResponseBean();
        List<TpAnnouncement> agreement = socialServiceI.getAnnouncement(communityId);
        responseBean.addSuccess(agreement);
        return responseBean;
    }

    @ApiOperation(value = "获取活动轮播图", notes = "获取活动轮播图")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", dataType = "String", name = "communityId", value = "小区id")
    })
    @RequestMapping(value = "/activity/Img/{communityId}", method = RequestMethod.GET)
    public ResponseBean getActivity(@PathVariable(value = "communityId") Integer communityId) {
        ResponseBean responseBean = new ResponseBean();
        List<TpActivity> agreement = socialServiceI.getActivity(communityId);
        responseBean.addSuccess(agreement);
        return responseBean;
    }


    @ApiOperation(value = "按小区获取分页活动列表", notes = "按小区获取分页活动列表,公告标题模糊查询")
    @ApiImplicitParams({@ApiImplicitParam(paramType = "path", dataType = "String", name = "communityId", value = "小区Id"),
            @ApiImplicitParam(paramType = "query", dataType = "String", name = "title", value = "活动标题"),
            @ApiImplicitParam(paramType = "query", dataType = "integer", name = "pageNum", value = "分页第几页"),
            @ApiImplicitParam(paramType = "query", dataType = "integer", name = "pageSize", value = "分页每页长度")})
    @RequestMapping(value = "/activitys/{communityId}", method = RequestMethod.GET)
    public ResponseBean getActivitys(@PathVariable Integer communityId, @RequestParam String title,
                                     @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                     @RequestParam(value = "pageSize", defaultValue = "5") Integer pageSize) {
        ResponseBean responseBean = new ResponseBean();
        List<TpActivity> activityList = socialServiceI.getActivitys(communityId, title, pageNum, pageSize);
        responseBean.addSuccess(activityList);
        return responseBean;
    }

    @ApiOperation(value = "论坛活动帖子详情", notes = "获取论坛活动帖子详情")
    @ApiImplicitParams({@ApiImplicitParam(paramType = "path", dataType = "integer", name = "communityId", value = "小区Id"),
            @ApiImplicitParam(paramType = "query", dataType = "integer", name = "activityId", value = "活动帖子id"),
            @ApiImplicitParam(paramType = "header",dataType = "String",name = "X-Auth-Token",value = "Token")})
    @RequestMapping(value = "/activity/{communityId}", method = RequestMethod.GET)
    public ResponseBean findActivityDetail(@PathVariable(value = "communityId") Integer communityId, @RequestParam("activityId") Integer activityId, HttpSession session) {
        UserElement userElement = (UserElement) session.getAttribute(Constant.APP_USER_SESSION);
        Integer userId = userElement.getId();
        ResponseBean responseBean = new ResponseBean();
        TpActivity activity = socialServiceI.findActivityDetail(activityId, communityId, userId);
        responseBean.addSuccess(activity);
        return responseBean;
    }

    @ApiOperation(value = "二手租赁详情", notes = "二手租赁详情")
    @ApiImplicitParams({@ApiImplicitParam(paramType = "path", dataType = "integer", name = "communityId", value = "小区Id"),
            @ApiImplicitParam(paramType = "query", dataType = "integer", name = "activityId", value = "活动帖子id"),
            @ApiImplicitParam(paramType = "header",dataType = "String",name = "X-Auth-Token",value = "Token")})
    @RequestMapping(value = "/getTransaction/{communityId}", method = RequestMethod.GET)
    public ResponseBean findUsedDetails(@PathVariable(value = "communityId") Integer communityId, @RequestParam("activityId") Integer activityId, HttpSession session) {
        ResponseBean responseBean = new ResponseBean();
        UserElement userElement = (UserElement) session.getAttribute(Constant.APP_USER_SESSION);
        Integer userId = userElement.getId();
        TpTransaction activity = socialServiceI.findUsedDetails(activityId, communityId, userId);
        responseBean.addSuccess(activity);
        return responseBean;
    }

    @ApiOperation(value = "获取所有的二手租赁帖子", notes = "获取所有的二手租赁帖子")
    @ApiImplicitParams({@ApiImplicitParam(paramType = "path", dataType = "integer", name = "communityId", value = "小区Id"),
            @ApiImplicitParam(paramType = "query", dataType = "String", name = "type", value = "帖子类型"),
            @ApiImplicitParam(paramType = "query", dataType = "integer", name = "pageNum", value = "分页第几页"),
            @ApiImplicitParam(paramType = "query", dataType = "integer", name = "pageSize", value = "分页每页长度")})
    @RequestMapping(value = "/getTransactions /{communityId}", method = RequestMethod.GET)
    public ResponseBean getAllPosts(@PathVariable("communityId") Integer communityId, @RequestParam("type") String type,
                                    @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                    @RequestParam(value = "pageSize", defaultValue = "5") Integer pageSize) {
        ResponseBean responseBean = new ResponseBean();
        List<TpTransaction> tpTransactions = socialServiceI.findAllTransaction(communityId, type, pageNum, pageSize);
        responseBean.addSuccess(tpTransactions);
        return responseBean;
    }

    @ApiOperation(value = "添加二手租赁帖子", notes = "添加二手租赁帖子")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataType = "String", name = "paramets", value ="title:小区标题, imageUrl:图片URL地址, content:小区内容, type:0二手,1求购,2租赁"),
            @ApiImplicitParam(paramType = "header",dataType = "String",name = "X-Auth-Token",value = "Token")
    })
    @RequestMapping(value = "/addTransaction", method = RequestMethod.POST)
    @ResponseBody
    public ResponseBean addTransaction(@RequestBody String paramets, HttpSession session)throws IOException{

        ResponseBean responseBean = new ResponseBean();
        UserElement userElement = (UserElement) session.getAttribute(Constant.APP_USER_SESSION);
        Integer userId = userElement.getId();
        ResponseBean response = socialServiceI.addAllTransaction(userId, paramets);
        return response;
    }

    @ApiOperation(value = "获取我发布所有二手租赁帖子", notes = "获取我发布所有二手租赁帖子")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "query", dataType = "String", name = "type", value = "帖子类型"),
            @ApiImplicitParam(paramType = "query", dataType = "integer", name = "pageNum", value = "分页第几页"),
            @ApiImplicitParam(paramType = "query", dataType = "integer", name = "pageSize", value = "分页每页长度"),
            @ApiImplicitParam(paramType = "header",dataType = "String",name = "X-Auth-Token",value = "Token")
    })
    @RequestMapping(value = "/selectAllTransaction", method = RequestMethod.GET)
    public ResponseBean selectAllTransaction(HttpSession session,
                                             @RequestParam("type") Integer type,
                                             @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                             @RequestParam(value = "pageSize", defaultValue = "5") Integer pageSize) {
        ResponseBean responseBean = new ResponseBean();
        UserElement userElement = (UserElement) session.getAttribute(Constant.APP_USER_SESSION);
        Integer userId = userElement.getId();
        ResponseBean response = socialServiceI.selectAllTransaction(userId, pageNum, pageSize,type);
        return response;
    }

    @ApiOperation(value = "修改二手租赁帖子", notes = "修改二手租赁帖子")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataType = "String", name = "paramets", value =
                    "id:小区id,title:小区标题，content：小区内容"),
            @ApiImplicitParam(paramType = "header",dataType = "String",name = "X-Auth-Token",value = "Token")
    })
    @RequestMapping(value = "/updateTransaction/{Id}", method = RequestMethod.PUT)
    public ResponseBean ubdateTransaction(HttpSession session, @RequestBody String paramets) {
        ResponseBean responseBean = new ResponseBean();
        UserElement userElement = (UserElement) session.getAttribute(Constant.APP_USER_SESSION);
        Integer userId = userElement.getId();
        ResponseBean response = socialServiceI.updateTransaction(paramets, userId);
        return response;
    }

    @ApiOperation(value = "评价工单内容以及评分", notes = "评价工单内容以及评分")
    @ApiImplicitParams({@ApiImplicitParam(paramType = "path", dataType = "integer", name = "communityId", value = "小区Id"),
            @ApiImplicitParam(name = "tpTicket", value = "报修", required = true, dataType = "TpTicket"),
            @ApiImplicitParam(paramType = "query", dataType = "integer", name = "ticketId", value = "工单Id"),
            @ApiImplicitParam(paramType = "header",dataType = "String",name = "X-Auth-Token",value = "Token")})
    @RequestMapping(value = "/accessTicket/{communityId}", method = RequestMethod.POST)
    public ResponseBean accessTicket(@PathVariable("communityId") Integer communityId, @RequestBody TpTicket tpTicket, @RequestParam("ticketId") String ticketId, HttpSession session) {
        UserElement userElement = (UserElement) session.getAttribute(Constant.APP_USER_SESSION);
        Integer userId = userElement.getId();
        ResponseBean responseBean = new ResponseBean();
        socialServiceI.accessTicket(communityId, tpTicket, ticketId, userId);
        return responseBean;
    }
}
