package com.community.huiju.service.impl;


import com.alibaba.fastjson.JSONObject;
import com.community.commom.constant.Constant;
import com.community.commom.mode.ResponseBean;
import com.community.huiju.dao.*;
import com.community.huiju.model.*;
import com.community.huiju.service.ITicketService;
import com.community.huiju.vo.TpTicketVO;
import com.github.pagehelper.PageHelper;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.IOException;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 工单业务 实现
 * @author weiximei
 */
@Service("iTicketService")
@Slf4j
public class TicketServiceImpl implements ITicketService {

    @Autowired
    private TpTicketMapper tpTicketMapper;

    @Autowired
    private TpTicketRecordMapper tpTicketRecordMapper;

    @Autowired
    private TpTicketRecordCommentMapper tpTicketRecordCommentMapper;

    @Autowired
    private TaUserMapper taUserMapper;

    @Autowired
    private TdImagesMapper tdImagesMapper;

    @Override
    public ResponseBean getList(TpTicket tpTicket, Integer pageNum, Integer pageSize) {

        ResponseBean<Map<String, Object>> responseBean = new ResponseBean();
        // 最终返回值
        Map<String, Object> result = Maps.newHashMap();

        Map<String, Object> parameter = Maps.newHashMap();
        parameter.put("communityId", tpTicket.getCommunityId());
        parameter.put("taUserId", tpTicket.getTaUserId());

        //  0 代表 报修  1 代表 投诉  2代表 联系单
        parameter.put("type", 0);
        // 报修
        PageHelper.startPage(pageNum, pageSize);
        List<TpTicket> tpTicketRepairsList = tpTicketMapper.selectByCommuniytIdAndByTaUserIdAndByType(parameter);
        List<TpTicketVO> repairsList = Lists.newArrayList();
        tpTicketVOConvert(tpTicketRepairsList, repairsList);

        // 投诉
        //  0 代表 报修  1 代表 投诉  2代表 联系单
        parameter.put("type", 1);
        PageHelper.startPage(pageNum, pageSize);
        List<TpTicket> tpTicketComplaintList = tpTicketMapper.selectByCommuniytIdAndByTaUserIdAndByType(parameter);
        List<TpTicketVO> complaintList = Lists.newArrayList();
        tpTicketVOConvert(tpTicketComplaintList, complaintList);

        // 联系工单
        //  0 代表 报修  1 代表 投诉  2代表 联系单
        parameter.put("type", 2);
        PageHelper.startPage(pageNum, pageSize);
        List<TpTicket> tpTicketLiaisonList = tpTicketMapper.selectByCommuniytIdAndByTaUserIdAndByType(parameter);
        List<TpTicketVO> liaisonList = Lists.newArrayList();
        tpTicketVOConvert(tpTicketLiaisonList, liaisonList);

        result.put("repairs", repairsList);
        result.put("complaint", complaintList);
        result.put("liaison", liaisonList);

        responseBean.addSuccess(result);
        return responseBean;
    }

    /**
     * 公共方法, 获取一条数据
     *
     * @param map
     * @return
     */
    private TpTicketRecordComment getTicketRecordComment(Map map) {
        List<TpTicketRecordComment> list = tpTicketRecordCommentMapper.selectByTicketId(map);
        return null == list
                ? null : list.size() == 0
                ? null : list.get(0);
    }

    /**
     * 数据转换,并填充数据
     *
     * @param target
     * @param source
     * @return
     */
    public void tpTicketVOConvert(List<TpTicket> source, List<TpTicketVO> target) {

        // 查询参数
        Map<String, Object> lastRecordMap = Maps.newHashMap();
        // 表示查询出最新的一条
        lastRecordMap.put("size", 1);

        source.stream().forEach(e -> {
            TpTicketVO tpTicketVO = new TpTicketVO();
            BeanUtils.copyProperties(e, tpTicketVO);
            // 设置工单编号
            lastRecordMap.put("tickerId", e.getId());
            TpTicketRecordComment comment = getTicketRecordComment(lastRecordMap);
            if (null != comment) {
                tpTicketVO.setCommentContent(comment.getContent());
                tpTicketVO.setCommentCreateDate(comment.getCreateDate());
            }

            target.add(tpTicketVO);
        });
    }

    @Override
    public ResponseBean getByTypeList(TpTicket tpTicket, Integer pageNum, Integer pageSize) {

        ResponseBean response = new ResponseBean();

        Map<String, Object> parameter = Maps.newHashMap();
        parameter.put("communityId", tpTicket.getCommunityId());
        parameter.put("taUserId", tpTicket.getTaUserId());

        //  0 代表 报修  1 代表 投诉  2代表 联系单
        parameter.put("type", tpTicket.getType());

        PageHelper.startPage(pageNum, pageSize);
        List<TpTicket> tpTicketList = tpTicketMapper.selectByCommuniytIdAndByTaUserIdAndByType(parameter);

        List<TpTicketVO> tpTicketVOList = Lists.newArrayList();
        tpTicketVOConvert(tpTicketList, tpTicketVOList);

        response.addSuccess(tpTicketVOList);

        return response;
    }

    /**
     * 获取报修详情
     *
     * @param communityId
     * @param ticketId
     * @return
     */
    @Override
    public TpTicket getTicketSchedule(String communityId, Integer ticketId) {
        //查看工单详情
        TpTicket ticket = tpTicketMapper.selectByTicketId(communityId, ticketId);
        if (null != ticket) {
            //工单进度
            List<TpTicketRecord> ticketRecordList = tpTicketRecordMapper.getTicketRecordByTicketId(communityId, ticketId);
            //工单回复
            ticketRecordList.stream().forEach(TpTicketRecord -> {
                List<TpTicketRecordComment> ticketRecordCommentList = tpTicketRecordCommentMapper.selectByTicketRecordId(TpTicketRecord);
                TpTicketRecord.setTicketRecordCommentList(ticketRecordCommentList);
            });
            ticket.setTicketRecordList(ticketRecordList);
        }
        return ticket;
    }

    @Override
    public ResponseBean addAiTicketService(Integer userId, String parameter) throws IOException {
        ResponseBean response = new ResponseBean();
        JSONObject jsonObject = JSONObject.parseObject(parameter);
        String ticketContent = (String) jsonObject.get("ticketContent");
        String ticketTitle = (String) jsonObject.get("ticketTitle");
        String repairType = (String) jsonObject.get("repairType");
        String imageUrl = (String) jsonObject.get("imageUrl");

        TaUser user = taUserMapper.selectByPrimaryKey(userId);

        TpTicket tpTicket=new TpTicket();
        tpTicket.setCommunityId(user.getCommunityId());
        tpTicket.setTaUserId(userId);
        tpTicket.setStatus("2");
        tpTicket.setRepairType(repairType);
        tpTicket.setTicketTitle(ticketTitle);
        tpTicket.setTicketContent(ticketContent);
        tpTicket.setCreateUser(userId);
        tpTicket.setCreateDate(new Date());
        tpTicket.setUpdateUser(userId);
        tpTicket.setUpdateDate(new Date());


        tpTicketMapper.insertSelective(tpTicket);
        insertTdImage(tpTicket, imageUrl, userId);

        Integer id=tpTicket.getId();
        TpTicketRecord tpTicketRecord = new TpTicketRecord();
        //获取当前插入的信息，维护工单记录表
        TpTicket tpTicketReco = tpTicketMapper.selectByPrimaryKey(id);
        tpTicketRecord.setCommunityId(user.getCommunityId());
        tpTicketRecord.setTicketId(tpTicketReco.getId());
        tpTicketRecord.setStatus(tpTicketReco.getStatus());
        tpTicketRecord.setCreateUser(userId);
        tpTicketRecord.setCreateDate(new Date());

        tpTicketRecordMapper.insertSelective(tpTicketRecord);
        response.addSuccess(tpTicketReco);
        return response;
    }

    private void insertTdImage(TpTicket tpTicket, String imageUrl, Integer userId) throws IOException {
        TdImages tdImages = new TdImages();
        Integer uuId = tpTicket.getId();
        tdImages.setImageUrl(imageUrl);
        tdImages.setType(Constant.SERVICE);
        tdImages.setUuid(uuId);
        tdImages.setCreateUser(userId);
        tdImages.setCreateTime(new Date());
        tdImagesMapper.insertSelective(tdImages);
    }

    /**
     * 回复工单
     * @param tpTicketRecordComment
     * @return
     */
    @Override
    public Integer updateTicketsReply(TpTicketRecordComment tpTicketRecordComment, Integer userId) {
        //查询用户名
        TaUser taUser = taUserMapper.selectByPrimaryKey(userId);
        
        tpTicketRecordComment.setUserName(taUser.getUserName());
        tpTicketRecordComment.setParentId(tpTicketRecordComment.getTicketRecordCommentId());
        tpTicketRecordComment.setUuid(userId);
        tpTicketRecordComment.setUserType(Constant.TICKET_USER_TYPE);
        tpTicketRecordComment.setCreateDate(new Date());
        //插入回复数据
        return tpTicketRecordCommentMapper.insertSelective(tpTicketRecordComment);
    }

    @Override
    public void updateTicketContent(Integer ticketId, TpTicket tpTicket, String type) {
        tpTicket.setId(ticketId);
        tpTicket.setType(type);
        tpTicketMapper.updateByPrimaryKeySelective(tpTicket);
    }

    @Transactional
    @Override
    public ResponseBean stopTpTicketRecord(Integer communityId, Integer ticketId, Integer userId) {
        ResponseBean responseBean = new ResponseBean();
        try{
            TpTicket tpTicket = new TpTicket();
            tpTicket.setStatus("6");
            tpTicket.setId(ticketId);
            tpTicketMapper.updateByPrimaryKeySelective(tpTicket);

            TpTicketRecord tpTicketRecord = new TpTicketRecord();
            tpTicketRecord.setStatus("6");
            tpTicketRecord.setTicketId(ticketId);
            tpTicketRecord.setCommunityId(communityId);
            //TODO
            tpTicketRecord.setCreateUser(userId);
            tpTicketRecord.setCreateDate(new Date());
            tpTicketRecordMapper.insertSelective(tpTicketRecord);
            return responseBean;
        }catch(Exception e){
            e.printStackTrace();
            responseBean.addError("服务器异常");
            return responseBean;
        }
    }
}
