package com.community.huiju.service.impl;

import com.community.commom.constant.Constant;
import com.community.huiju.dao.ToCommunitiesMapper;
import com.community.huiju.dao.TpUserCommunityMapper;
import com.community.huiju.dao.TpUserMapper;
import com.community.huiju.model.ToCommunities;
import com.community.huiju.model.TpUser;
import com.community.huiju.model.TpUserCommunity;
import com.community.huiju.service.CommunityServiceI;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author FXF
 * @date 2018-10-31
 */
@Service("communityService")
@Transactional
public class CommunityServiceImpl implements CommunityServiceI {
	
	@Autowired
	private ToCommunitiesMapper toCommunitiesMapper;
	
	@Autowired
	private TpUserMapper tpUserMapper;
	
	@Autowired
	private TpUserCommunityMapper tpUserCommunityMapper;
	
	/**
	 * 分页获取小区列表
	 * @param toCommunities
	 * @param pageNum
	 * @param pageSize
	 * @return
	 */
	@Override
	public Map<String,Object> getCommunitys(ToCommunities toCommunities, Integer pageNum, Integer pageSize) {
		//使用分页插件
		Page page = PageHelper.startPage(pageNum, pageSize);
		//获取数据
		List<ToCommunities> list = toCommunitiesMapper.selectByCommunityName(toCommunities);
		Map<String,Object> map = new HashMap<>();
		map.put("items",list);
		map.put("total",page.getTotal());
		return map;
	}
	
	@Override
	public Integer addCommunity(ToCommunities toCommunities) {
		Integer size = toCommunitiesMapper.insertSelective(toCommunities);
		if (size < 1){
			return 0;
		}
		
		//构建用户信息
		TpUser tpUser = new TpUser();
		tpUser.setCommunityId(toCommunities.getId());
		tpUser.setUserName(toCommunities.getUserName());
		tpUser.setLoginName(toCommunities.getLoginName());
		tpUser.setCreateDate(new Date());
		tpUser.setCreateUser(1);
		tpUser.setStatus(Constant.EFFECTIVE);
		//插入用户信息
		tpUserMapper.insertSelective(tpUser);
		//维护住户端用户与社区关系表
		TpUserCommunity tpUserCommunity = new TpUserCommunity();
		tpUserCommunity.setTpUserId(tpUser.getId());
		tpUserCommunity.setCommunityId(tpUser.getCommunityId());
		tpUserCommunityMapper.insertSelective(tpUserCommunity);
		return size;
	}
	
	/**
	 * 根据详情获取小区数据
	 * @param id
	 * @return
	 */
	@Override
	public ToCommunities getCommunityById(Integer id) {
		return toCommunitiesMapper.selectByPrimaryKey(id);
	}
	
	/**
	 * 根据小区id更新数据
	 * @param toCommunities
	 * @return
	 */
	@Override
	public Integer updateCommunityById(ToCommunities toCommunities) {
		return toCommunitiesMapper.updateByPrimaryKeySelective(toCommunities);
	}
}
