package com.community.huiju.service.impl;

import com.community.commom.mode.ResponseBean;
import com.community.commom.utils.AccountValidatorUtil;
import com.community.huiju.common.code.cache.AppkeyCache;
import com.community.huiju.dao.ToSysRoleMapper;
import com.community.huiju.dao.ToUserMapper;
import com.community.huiju.model.ToSysRole;
import com.community.huiju.model.ToUser;
import com.community.huiju.service.IToUserService;
import com.community.huiju.vo.ToUserVO;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service("iToUserServer")
@Slf4j
public class ToUserServerImpl implements IToUserService {

    @Autowired
    private ToUserMapper toUserMapper;

    @Autowired
    private ToSysRoleMapper toSysRoleMapper;

    @Override
    public ResponseBean login(String loginName, String code) {

        ResponseBean response = new ResponseBean();
        String phoneCode = (String) AppkeyCache.getCache(loginName);
        if (!phoneCode.equals(code)) {
            response.addError("验证码错误!");
            return response;
        }
        // 设置验证码为null字符
        AppkeyCache.setCache(loginName,"null");
        log.info("{} 手机号校验结果: {}",loginName,AccountValidatorUtil.isPhone(loginName));
        if (!AccountValidatorUtil.isPhone(loginName)){
            response.addError("请输入正取的手机号!");
            return response;
        }
        if (StringUtils.isBlank(code)) {
            response.addError("请输入验证码!");
            return response;
        }

        ToUser currentUser = toUserMapper.selectByLoginName(loginName);
        if (null == currentUser) {
            response.addError("用户不存在!");
            return response;
        }

        ToUserVO userVO = new ToUserVO();
        BeanUtils.copyProperties(currentUser,userVO);
        response.addSuccess(userVO);
        return response;
    }


    @Override
    public ResponseBean getInfo(Integer userId) {
        ResponseBean response = new ResponseBean();
        ToUser toUser = toUserMapper.selectByPrimaryKey(userId);
        if (toUser == null) {
            response.addError("用户不存在!");
            return response;
        }

        ToUserVO toUserVO = new ToUserVO();
        BeanUtils.copyProperties(toUser,toUserVO);

        List<ToSysRole> sysRoleList = toSysRoleMapper.selectRoleByUserId(userId);
        toUserVO.setRoles(sysRoleList);

        response.addSuccess(toUserVO);

        return response;
    }
}
